XXHash64Sink class

Inheritance

Constructors

XXHash64Sink(int seed)

Properties

bdata ↔ ByteData
The buffer as ByteData
latefinalinherited
blockLength → int
The internal block length of the algorithm in bytes
finalinherited
buffer ↔ Uint8List
The main buffer
latefinalinherited
closed → bool
Returns true if the sink is closed, false otherwise
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hashLength → int
The length of generated hash in bytes
final
messageLength ↔ int
The message length in bytes
getter/setter pairinherited
messageLengthInBits → int
Get the message length in bits
no setterinherited
pos ↔ int
The current position of data in the buffer
getter/setter pairinherited
qbuffer → Uint64List
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sbuffer ↔ Uint32List
The buffer as Uint32List
latefinalinherited
seed → int
final

Methods

$finalize() → Uint8List
Finalizes the message digest with the remaining message block, and returns the output as byte array.
override
$process(List<int> chunk, int start, int end) → void
Processes a chunk of input data
override
$update([List<int>? block, int offset = 0, bool last = false]) → void
Internal method to update the message-digest with a single block.
override
add(List<int> data, [int start = 0, int? end]) → void
Adds data to the message-digest.
inherited
close() → void
Finalizes the message-digest. It calls digest method internally.
inherited
digest() → HashDigest
Finalizes the message-digest and returns a HashDigest
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Resets the current state to start from fresh state
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

prime64_1 → const int
prime64_2 → const int
prime64_3 → const int
prime64_4 → const int
prime64_5 → const int